==> Xarm-1.2.7.tar.gz: Xarm-1.2.7/include/Xarm/Separator.h <==
/* $Id: Separator.h,v 1.2 1997/04/07 15:33:22 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_SEPARATOR_H_)
#define _XARM_SEPARATOR_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Primitive.h>

class SeparatorClass : public PrimitiveClass {
 protected:
   SeparatorClass() {}
   virtual WidgetClass classPointer() { return xmSeparatorWidgetClass; }
   virtual _XtString className() { return (_XtString) "XmSeparator"; }
 public:
   /* resources */
   void margin(Dimension);
   Dimension margin();
   void orientation(unsigned char);
   unsigned char orientation();
   void separatorType(unsigned char);
   unsigned char separatorType();
};

class Separator : public SeparatorClass {
 public:
   Separator(Widget w_parent, 
             ArgList arglist = NULL, 
             Cardinal cnt = 0,
             _XtString name = NULL);
   Separator(_XtString name, Widget w_parent);
   Separator(Widget w_parent, XarmArg &args, _XtString name);
};

#endif

==> Xarm-1.3.0.tar.gz: Xarm-1.3.0/include/Xarm/Separator.h <==
/* $Id: Separator.h,v 1.2 1997/04/07 15:33:22 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_SEPARATOR_H_)
#define _XARM_SEPARATOR_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Primitive.h>

class SeparatorClass : public PrimitiveClass {
 protected:
   SeparatorClass() {}
   virtual WidgetClass classPointer() { return xmSeparatorWidgetClass; }
   virtual _XtString className() { return (_XtString) "XmSeparator"; }
 public:
   /* resources */
   void margin(Dimension);
   Dimension margin() const;
   void orientation(unsigned char);
   unsigned char orientation() const;
   void separatorType(unsigned char);
   unsigned char separatorType() const;
};

class Separator : public SeparatorClass {
 public:
   Separator(Widget w_parent, 
             ArgList arglist = NULL, 
             Cardinal cnt = 0,
             _XtString name = NULL);
   Separator(_XtString name, Widget w_parent);
   Separator(Widget w_parent, XarmArg &args, _XtString name);
};

#endif
